@@ -4,7 +4,7 @@
 #include <stdio.h>
 #include "mem.h"
 
-void encrypt_file (FILE* input, FILE* output, int algo);
+void encrypt_file (FILE* input, long int fsize, FILE* output, int algo);
 
 #endif
 
